# Generated by roxygen2: do not edit by hand

S3method(print,xtcsdq)
S3method(print,xtqsh)
S3method(summary,xtcsdq)
S3method(summary,xtqsh)
export(xtcsdq)
export(xtmispanel)
export(xtpretest)
export(xtqsh)
importFrom(stats,complete.cases)
