\name{print.xtqsh}
\alias{print.xtqsh}
\title{Print Method for xtqsh Objects}
\description{Prints a formatted summary of an \code{"xtqsh"} test result.}
\usage{
\method{print}{xtqsh}(x, \dots)
}
\arguments{
  \item{x}{An object of class \code{"xtqsh"}.}
  \item{\dots}{Additional arguments (ignored).}
}
\value{Invisibly returns \code{x}.}
\keyword{print}
