\name{qsh_sample}
\alias{qsh_sample}
\docType{data}
\title{Sample Panel Dataset for Quantile Slope Homogeneity Testing}
\description{
A simulated balanced panel dataset for demonstrating the quantile slope
homogeneity test (\code{\link{xtqsh}}).
}
\usage{data(qsh_sample)}
\format{
A data frame with columns:
\describe{
  \item{id}{Cross-sectional unit identifier.}
  \item{time}{Time period identifier.}
  \item{y}{Dependent variable.}
  \item{x1}{First explanatory variable.}
  \item{x2}{Second explanatory variable.}
}
}
\keyword{datasets}
