\name{summary.xtqsh}
\alias{summary.xtqsh}
\title{Summary Method for xtqsh Objects}
\description{Prints a summary of an \code{"xtqsh"} test result.}
\usage{
\method{summary}{xtqsh}(object, \dots)
}
\arguments{
  \item{object}{An object of class \code{"xtqsh"}.}
  \item{\dots}{Additional arguments (ignored).}
}
\value{Invisibly returns \code{object}.}
\keyword{print}
