% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/xtcsdq.R
\name{summary.xtcsdq}
\alias{summary.xtcsdq}
\title{Summary method for xtcsdq objects}
\usage{
\method{summary}{xtcsdq}(object, ...)
}
\arguments{
\item{object}{An object of class \code{"xtcsdq"}.}

\item{...}{Additional arguments (ignored).}
}
\value{
Invisibly returns \code{object}.
}
\description{
Summary method for xtcsdq objects
}
